@@ -1,6 +1,7 @@
+import abc
 import warnings
 from collections.abc import Sequence
-from copy import copy
+from copy import deepcopy
 from typing import Any, cast
 
 import numpy as np
@@ -32,7 +33,20 @@ from pytensor.tensor.utils import _parse_gufunc_signature, safe_signature
 from pytensor.tensor.variable import TensorVariable
 
 
-class RandomVariable(Op):
+class RNGConsumerOp(Op):
+    """Baseclass for Ops that consume RNGs."""
+
+    @abc.abstractmethod
+    def update(self, node: Apply) -> dict[Variable, Variable]:
+        """Symbolic update expression for input RNG variables.
+
+        Returns a dictionary with the symbolic expressions required for correct updating
+        of RNG variables in repeated function evaluations.
+        """
+        pass
+
+
+class RandomVariable(RNGConsumerOp):
     """An `Op` that produces a sample from a random variable.
 
     This is essentially `RandomFunction`, except that it removes the
@@ -112,6 +126,8 @@ class RandomVariable(Op):
             else:
                 self.signature = safe_signature(self.ndims_params, [self.ndim_supp])
 
+        if isinstance(dtype, np.dtype):
+            dtype = dtype.name
         self.dtype = dtype or getattr(self, "dtype", None)
 
         self.inplace = (
@@ -121,6 +137,9 @@ class RandomVariable(Op):
         if self.inplace:
             self.destroy_map = {0: [0]}
 
+    def update(self, node: Apply) -> dict[Variable, Variable]:
+        return {node.inputs[0]: node.outputs[0]}
+
     def _supp_shape_from_params(self, dist_params, param_shapes=None):
         """Determine the support shape of a multivariate `RandomVariable`'s output given its parameters.
 
@@ -151,11 +170,13 @@ class RandomVariable(Op):
 
             # Try to infer missing support dims from signature of params
             for param, param_sig, ndim_params in zip(
-                dist_params, self.inputs_sig, self.ndims_params
+                dist_params, self.inputs_sig, self.ndims_params, strict=True
             ):
                 if ndim_params == 0:
                     continue
-                for param_dim, dim in zip(param.shape[-ndim_params:], param_sig):
+                for param_dim, dim in zip(
+                    param.shape[-ndim_params:], param_sig, strict=True
+                ):
                     if dim in core_out_shape and core_out_shape[dim] is None:
                         core_out_shape[dim] = param_dim
 
@@ -230,7 +251,7 @@ class RandomVariable(Op):
 
             # Fail early when size is incompatible with parameters
             for i, (param, param_ndim_supp) in enumerate(
-                zip(dist_params, self.ndims_params)
+                zip(dist_params, self.ndims_params, strict=True)
             ):
                 param_batched_dims = getattr(param, "ndim", 0) - param_ndim_supp
                 if param_batched_dims > size_len:
@@ -254,7 +275,7 @@ class RandomVariable(Op):
 
             batch_shape = tuple(
                 s if not b else constant(1, "int64")
-                for s, b in zip(shape[:-n], p.type.broadcastable[:-n])
+                for s, b in zip(shape[:-n], p.type.broadcastable[:-n], strict=True)
             )
             return batch_shape
 
@@ -263,7 +284,9 @@ class RandomVariable(Op):
         # independent variate dimensions are left.
         params_batch_shape = tuple(
             extract_batch_shape(p, ps, n)
-            for p, ps, n in zip(dist_params, param_shapes, self.ndims_params)
+            for p, ps, n in zip(
+                dist_params, param_shapes, self.ndims_params, strict=False
+            )
         )
 
         if len(params_batch_shape) == 1:
@@ -391,7 +414,7 @@ class RandomVariable(Op):
 
         # Draw from `rng` if `self.inplace` is `True`, and from a copy of `rng` otherwise.
         if not self.inplace:
-            rng = copy(rng)
+            rng = deepcopy(rng)
 
         outputs[0][0] = rng
         outputs[1][0] = np.asarray(
